#!/bin/bash
#
# Workload Automation v2 for LAVA
#
# Copyright (C) 2014, Linaro Limited.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# Author: Milosz Wasilewski <milosz.wasilewski@linaro.org>
# Author: Naresh Kamboju <naresh.kamboju@linaro.org>
#

set -e
echo "Preparing device for mode: $1"

disable_iks () {
    IPADDR=`cat IPADDR`
    echo "Disable IKS for $IPADDR"
    echo "adb -s $IPADDR:5555 shell \"echo 0 > /sys/kernel/bL_switcher/active\""
    adb -s $IPADDR:5555 shell "echo 0 > /sys/kernel/bL_switcher/active"
    adb -s $IPADDR:5555 shell "cat /sys/kernel/bL_switcher/active"
}

if [ $1 == 'iks' ]
then
    # enable IKS
    IPADDR=`cat IPADDR`
    echo "Enable IKS for $IPADDR"
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    echo "adb -s $IPADDR:5555 shell \"echo 1 > /sys/kernel/bL_switcher/active\""
    adb -s $IPADDR:5555 shell "echo 1 > /sys/kernel/bL_switcher/active"
    adb -s $IPADDR:5555 shell "cat /sys/kernel/bL_switcher/active"
fi

if [ $1 == 'a7only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    echo "Disable A15 cluster"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu3/online"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu4/online"
fi

if [ $1 == 'a15only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    echo "Disable A7 cluster"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu0/online"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu1/online"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu2/online"
fi

if [ $1 == 'a53only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    adb devices
    echo "Disable A57 cluster"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu1/online | su"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu2/online | su"
    adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/go_hispeed_load | su"
    adb -s $IPADDR:5555 shell "echo 700000 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/hispeed_freq | su"
fi

if [ $1 == 'a57only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    adb devices
    echo "Disable A53 cluster"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu0/online | su"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu3/online | su"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu4/online | su"
    adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu5/online | su"
    adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/go_hispeed_load | su"
    adb -s $IPADDR:5555 shell "echo 800000 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/hispeed_freq | su"
fi

if [ $1 == 'hmp' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    adb devices
    if [ $2 == 'vexpress-tc2' ]
    then
        disable_iks
    fi
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 700000 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/hispeed_freq | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 800000 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

if [ $1 == 'easON_a53bc' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo ENERGY_AWARE > /sys/kernel/debug/sched_features | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 700000 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/hispeed_freq | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 800000 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

if [ $1 == 'easOFF_a53bc' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo NO_ENERGY_AWARE > /sys/kernel/debug/sched_features | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 700000 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/hispeed_freq | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 800000 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

if [ $1 == 'easON_a53only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo ENERGY_AWARE > /sys/kernel/debug/sched_features | su"
        echo "Disable A57 cluster"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu1/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu2/online | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 700000 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

if [ $1 == 'easOFF_a53only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo NO_ENERGY_AWARE > /sys/kernel/debug/sched_features | su"
        echo "Disable A57 cluster"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu1/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu2/online | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 700000 > /sys/devices/system/cpu/cpu0/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

if [ $1 == 'easON_a57only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo ENERGY_AWARE > /sys/kernel/debug/sched_features | su"
        echo "Disable A53 cluster"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu0/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu3/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu4/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu5/online | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 800000 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

if [ $1 == 'easOFF_a57only' ]
then
    IPADDR=`cat IPADDR`
    adb connect $IPADDR:5555
    adb devices
    echo "Waiting for device"
    adb wait-for-device
    if [ $2 == 'juno' ]
    then
        adb -s $IPADDR:5555 shell "echo NO_ENERGY_AWARE > /sys/kernel/debug/sched_features | su"
        echo "Disable A53 cluster"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu0/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu3/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu4/online | su"
        adb -s $IPADDR:5555 shell "echo 0 > /sys/devices/system/cpu/cpu5/online | su"
        adb -s $IPADDR:5555 shell "echo 85 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/go_hispeed_load | su"
        adb -s $IPADDR:5555 shell "echo 800000 > /sys/devices/system/cpu/cpu1/cpufreq/interactive/hispeed_freq | su"
    fi
    adb connect $IPADDR:5555
    adb wait-for-device
    adb devices
fi

exit 0
